@@ -1,6 +1,6 @@
-
-
-def constrain(val, start, end, realstart, realend, lessthan_sym=None, morethan_sym=None):
+def constrain(
+    val, start, end, realstart, realend, lessthan_sym=None, morethan_sym=None
+):
     # from hooman
     # mouseX 0 width 0 255
     # v = (mouseX / (end-start)) * (realend-realstart)
@@ -19,4 +19,4 @@ def constrain(val, start, end, realstart, realend, lessthan_sym=None, morethan_s
         else:
             return morethan_sym
     v = ((val - start) / (end - start)) * (realend - realstart)
-    return realstart + v
\ No newline at end of file
+    return realstart + v
